pub struct StorageProfile {
pub nfs_ip_address: Option<String>,
pub os_disks: Vec<Disk>,
}Expand description
Specifies the storage settings for the Azure Large Instance disks.
Fields
nfs_ip_address: Option<String>IP Address to connect to storage.
os_disks: Vec<Disk>Specifies information about the operating system disk used by Azure Large Instance.
Implementations